@@ -15,8 +15,13 @@
 from keystone import assignment
 from keystone import clean
 from keystone.common import kvs
+from keystone import config
 from keystone import exception
-from keystone.openstack.common.gettextutils import _
+from keystone.i18n import _
+from keystone.openstack.common import versionutils
+
+
+CONF = config.CONF
 
 
 class Assignment(kvs.Base, assignment.Driver):
@@ -49,6 +54,13 @@ class Assignment(kvs.Base, assignment.Driver):
 
     """
 
+    @versionutils.deprecated(versionutils.deprecated.JUNO,
+                             in_favor_of='keystone.assignment.backends.sql',
+                             remove_in=+1,
+                             what='keystone.assignment.backends.kvs')
+    def __init__(self):
+        super(Assignment, self).__init__()
+
     # Public interface
 
     def get_project(self, tenant_id):
@@ -67,7 +79,7 @@ class Assignment(kvs.Base, assignment.Driver):
     def list_projects_in_domain(self, domain_id):
         project_refs = self._build_project_refs()
         self.get_domain(domain_id)
-        return [ref for ref in project_refs if domain_id in ref['domain_id']]
+        return [ref for ref in project_refs if domain_id == ref['domain_id']]
 
     def get_project_by_name(self, tenant_name, domain_id):
         try:
@@ -119,6 +131,31 @@ class Assignment(kvs.Base, assignment.Driver):
         except exception.NotFound:
             raise exception.RoleNotFound(role_id=role_id)
 
+    def get_group_project_roles(self, groups, project_id, project_domain_id):
+        role_list = []
+        for group_id in groups:
+            try:
+                metadata_ref = self._get_metadata(
+                    group_id=group_id, tenant_id=project_id)
+                role_list += self._roles_from_role_dicts(
+                    metadata_ref.get('roles', {}), False)
+            except exception.MetadataNotFound:
+                # no group assignment, skip
+                pass
+
+            if CONF.os_inherit.enabled:
+                # Now get any inherited group roles for the owning domain
+                try:
+                    metadata_ref = self._get_metadata(
+                        group_id=group_id,
+                        domain_id=project_domain_id)
+                    role_list += self._roles_from_role_dicts(
+                        metadata_ref.get('roles', {}), True)
+                except exception.MetadataNotFound:
+                    pass
+
+        return role_list
+
     def list_roles(self, hints):
         return self._list_roles()
 
@@ -127,25 +164,43 @@ class Assignment(kvs.Base, assignment.Driver):
         return [self.get_role(x) for x in role_ids]
 
     def list_projects_for_user(self, user_id, group_ids, hints):
-        # NOTE(henry-nash): The kvs backend is being deprecated, so no
-        # support is provided for projects that the user has a role on solely
-        # by virtue of group membership.
-
         project_ids = set()
+        all_projects = self.list_projects(hints=None)
 
         metadata_keys = (k for k in self.db.keys()
-                         if k.startswith('metadata_user-'))
+                         if (k.startswith('metadata_user-') or
+                             k.startswith('metadata_group-')))
         for key in metadata_keys:
-            i, meta_project_or_domain_id, meta_user_id = key.split('-')
+            i, meta_project_or_domain_id, meta_entity_id = key.split('-')
 
-            if meta_user_id != user_id:
-                # Not the user, so on to next metadata.
+            if meta_entity_id != user_id and meta_entity_id not in group_ids:
+                # Not the user not one of the groups, so on to next metadata.
                 continue
 
             try:
                 self.get_project(meta_project_or_domain_id)
             except exception.NotFound:
-                # target is not a project, so on to next metadata.
+                # target is not a project, could it be a domain
+                if not CONF.os_inherit.enabled:
+                    # Inheritance is disabled, skip domain handling
+                    continue
+                try:
+                    self.get_domain(meta_project_or_domain_id)
+                except exception.NotFound:
+                    # Not a domain, move on
+                    continue
+
+                data = self.db.get(key)
+                for role in data.get('roles', []):
+                    if role['inherited_to'] == 'projects':
+                        # Role is inherited
+                        for project in all_projects:
+                            # add all projects for the domain to the list
+                            # of ids
+                            if (project['domain_id'] ==
+                                    meta_project_or_domain_id):
+                                project_ids.add(project['id'])
+                        break
                 continue
 
             project_id = meta_project_or_domain_id
@@ -158,6 +213,9 @@ class Assignment(kvs.Base, assignment.Driver):
 
         return project_refs
 
+    def list_domains_for_user(self, user_id, group_ids, hints):
+        raise exception.NotImplemented()
+
     def get_roles_for_groups(self, group_ids, project_id=None, domain_id=None):
         raise exception.NotImplemented()
 
@@ -559,7 +617,8 @@ class Assignment(kvs.Base, assignment.Driver):
         :raises: keystone.exception.RoleNotFound
 
         """
-        raise exception.NotImplemented()
+        # KVS doesn't bother cleaning up role assignments for the user. I
+        # guess it's too difficult to implement or something.
 
     def delete_group(self, group_id):
         """Deletes all assignments for a group.
@@ -567,4 +626,5 @@ class Assignment(kvs.Base, assignment.Driver):
         :raises: keystone.exception.RoleNotFound
 
         """
-        raise exception.NotImplemented()
+        # KVS doesn't bother cleaning up role assignments for the group. I
+        # guess it's too difficult to implement or something.
