@@ -19,45 +19,57 @@ import abc
 
 import six
 
+from keystone.common import cache
 from keystone.common import dependency
 from keystone.common import driver_hints
 from keystone.common import manager
 from keystone.common import utils
 from keystone import config
 from keystone import exception
-from keystone.openstack.common.gettextutils import _
+from keystone.i18n import _
+from keystone.i18n import _LE
+from keystone import notifications
 from keystone.openstack.common import log
 
 
 CONF = config.CONF
 LOG = log.getLogger(__name__)
+SHOULD_CACHE = cache.should_cache_fn('catalog')
+
+EXPIRATION_TIME = lambda: CONF.catalog.cache_time
 
 
-def format_url(url, data):
-    """Safely string formats a user-defined URL with the given data."""
-    data = utils.WhiteListedFormatter(
+def format_url(url, substitutions):
+    """Formats a user-defined URL with the given substitutions.
+
+    :param string url: the URL to be formatted
+    :param dict substitutions: the dictionary used for substitution
+    :returns: a formatted URL
+
+    """
+    substitutions = utils.WhiteListedItemFilter(
         CONF.catalog.endpoint_substitution_whitelist,
-        data)
+        substitutions)
     try:
-        result = url.replace('$(', '%(') % data
+        result = url.replace('$(', '%(') % substitutions
     except AttributeError:
         LOG.error(_('Malformed endpoint - %(url)r is not a string'),
                   {"url": url})
         raise exception.MalformedEndpoint(endpoint=url)
     except KeyError as e:
-        LOG.error(_("Malformed endpoint %(url)s - unknown key %(keyerror)s"),
+        LOG.error(_LE("Malformed endpoint %(url)s - unknown key %(keyerror)s"),
                   {"url": url,
                    "keyerror": e})
         raise exception.MalformedEndpoint(endpoint=url)
     except TypeError as e:
-        LOG.error(_("Malformed endpoint %(url)s - unknown key %(keyerror)s"
-                    "(are you missing brackets ?)"),
+        LOG.error(_LE("Malformed endpoint '%(url)s'. The following type error "
+                      "occurred during string substitution: %(typeerror)s"),
                   {"url": url,
-                   "keyerror": e})
+                   "typeerror": e})
         raise exception.MalformedEndpoint(endpoint=url)
     except ValueError as e:
-        LOG.error(_("Malformed endpoint %s - incomplete format "
-                    "(are you missing a type notifier ?)"), url)
+        LOG.error(_LE("Malformed endpoint %s - incomplete format "
+                      "(are you missing a type notifier ?)"), url)
         raise exception.MalformedEndpoint(endpoint=url)
     return result
 
@@ -70,10 +82,14 @@ class Manager(manager.Manager):
     dynamically calls the backend.
 
     """
+    _ENDPOINT = 'endpoint'
+    _SERVICE = 'service'
+    _REGION = 'region'
 
     def __init__(self):
         super(Manager, self).__init__(CONF.catalog.driver)
 
+    @notifications.created(_REGION, public=False, result_id_arg_attr='id')
     def create_region(self, region_ref):
         # Check duplicate ID
         try:
@@ -84,37 +100,68 @@ class Manager(manager.Manager):
             msg = _('Duplicate ID, %s.') % region_ref['id']
             raise exception.Conflict(type='region', details=msg)
 
+        # NOTE(lbragstad): The description column of the region database
+        # can not be null. So if the user doesn't pass in a description then
+        # set it to an empty string.
+        region_ref.setdefault('description', '')
         try:
             return self.driver.create_region(region_ref)
         except exception.NotFound:
             parent_region_id = region_ref.get('parent_region_id')
             raise exception.RegionNotFound(region_id=parent_region_id)
 
+    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
+                        expiration_time=EXPIRATION_TIME)
     def get_region(self, region_id):
         try:
             return self.driver.get_region(region_id)
         except exception.NotFound:
             raise exception.RegionNotFound(region_id=region_id)
 
+    @notifications.updated(_REGION, public=False)
+    def update_region(self, region_id, region_ref):
+        return self.driver.update_region(region_id, region_ref)
+
+    @notifications.deleted(_REGION, public=False)
     def delete_region(self, region_id):
         try:
-            return self.driver.delete_region(region_id)
+            ret = self.driver.delete_region(region_id)
+            self.get_region.invalidate(self, region_id)
+            return ret
         except exception.NotFound:
             raise exception.RegionNotFound(region_id=region_id)
 
+    @manager.response_truncated
+    def list_regions(self, hints=None):
+        return self.driver.list_regions(hints or driver_hints.Hints())
+
+    @notifications.created(_SERVICE, public=False)
     def create_service(self, service_id, service_ref):
         service_ref.setdefault('enabled', True)
         return self.driver.create_service(service_id, service_ref)
 
+    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
+                        expiration_time=EXPIRATION_TIME)
     def get_service(self, service_id):
         try:
             return self.driver.get_service(service_id)
         except exception.NotFound:
             raise exception.ServiceNotFound(service_id=service_id)
 
+    @notifications.updated(_SERVICE, public=False)
+    def update_service(self, service_id, service_ref):
+        return self.driver.update_service(service_id, service_ref)
+
+    @notifications.deleted(_SERVICE, public=False)
     def delete_service(self, service_id):
         try:
-            return self.driver.delete_service(service_id)
+            endpoints = self.list_endpoints()
+            ret = self.driver.delete_service(service_id)
+            self.get_service.invalidate(self, service_id)
+            for endpoint in endpoints:
+                if endpoint['service_id'] == service_id:
+                    self.get_endpoint.invalidate(self, endpoint['id'])
+            return ret
         except exception.NotFound:
             raise exception.ServiceNotFound(service_id=service_id)
 
@@ -122,19 +169,32 @@ class Manager(manager.Manager):
     def list_services(self, hints=None):
         return self.driver.list_services(hints or driver_hints.Hints())
 
+    @notifications.created(_ENDPOINT, public=False)
     def create_endpoint(self, endpoint_id, endpoint_ref):
         try:
             return self.driver.create_endpoint(endpoint_id, endpoint_ref)
+        except exception.RegionNotFound:
+            raise exception.ValidationError(attribute='endpoint region_id',
+                                            target='region table')
         except exception.NotFound:
             service_id = endpoint_ref.get('service_id')
             raise exception.ServiceNotFound(service_id=service_id)
 
+    @notifications.updated(_ENDPOINT, public=False)
+    def update_endpoint(self, endpoint_id, endpoint_ref):
+        return self.driver.update_endpoint(endpoint_id, endpoint_ref)
+
+    @notifications.deleted(_ENDPOINT, public=False)
     def delete_endpoint(self, endpoint_id):
         try:
-            return self.driver.delete_endpoint(endpoint_id)
+            ret = self.driver.delete_endpoint(endpoint_id)
+            self.get_endpoint.invalidate(self, endpoint_id)
+            return ret
         except exception.NotFound:
             raise exception.EndpointNotFound(endpoint_id=endpoint_id)
 
+    @cache.on_arguments(should_cache_fn=SHOULD_CACHE,
+                        expiration_time=EXPIRATION_TIME)
     def get_endpoint(self, endpoint_id):
         try:
             return self.driver.get_endpoint(endpoint_id)
@@ -167,16 +227,20 @@ class Driver(object):
         :raises: keystone.exception.RegionNotFound (if parent region invalid)
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def list_regions(self):
+    def list_regions(self, hints):
         """List all regions.
 
+        :param hints: contains the list of filters yet to be satisfied.
+                      Any filters satisfied here will be removed so that
+                      the caller will know if any filters remain.
+
         :returns: list of region_refs or an empty list.
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def get_region(self, region_id):
@@ -186,17 +250,17 @@ class Driver(object):
         :raises: keystone.exception.RegionNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def update_region(self, region_id):
+    def update_region(self, region_id, region_ref):
         """Update region by id.
 
         :returns: region_ref dict
         :raises: keystone.exception.RegionNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def delete_region(self, region_id):
@@ -205,7 +269,7 @@ class Driver(object):
         :raises: keystone.exception.RegionNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def create_service(self, service_id, service_ref):
@@ -214,16 +278,20 @@ class Driver(object):
         :raises: keystone.exception.Conflict
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def list_services(self):
+    def list_services(self, hints):
         """List all services.
 
+        :param hints: contains the list of filters yet to be satisfied.
+                      Any filters satisfied here will be removed so that
+                      the caller will know if any filters remain.
+
         :returns: list of service_refs or an empty list.
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def get_service(self, service_id):
@@ -233,17 +301,17 @@ class Driver(object):
         :raises: keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def update_service(self, service_id):
+    def update_service(self, service_id, service_ref):
         """Update service by id.
 
         :returns: service_ref dict
         :raises: keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def delete_service(self, service_id):
@@ -252,7 +320,7 @@ class Driver(object):
         :raises: keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def create_endpoint(self, endpoint_id, endpoint_ref):
@@ -262,7 +330,7 @@ class Driver(object):
                  keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def get_endpoint(self, endpoint_id):
@@ -272,16 +340,20 @@ class Driver(object):
         :raises: keystone.exception.EndpointNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def list_endpoints(self):
+    def list_endpoints(self, hints):
         """List all endpoints.
 
+        :param hints: contains the list of filters yet to be satisfied.
+                      Any filters satisfied here will be removed so that
+                      the caller will know if any filters remain.
+
         :returns: list of endpoint_refs or an empty list.
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def update_endpoint(self, endpoint_id, endpoint_ref):
@@ -292,7 +364,7 @@ class Driver(object):
                  keystone.exception.ServiceNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def delete_endpoint(self, endpoint_id):
@@ -301,7 +373,7 @@ class Driver(object):
         :raises: keystone.exception.EndpointNotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
     def get_catalog(self, user_id, tenant_id, metadata=None):
@@ -326,7 +398,7 @@ class Driver(object):
         :raises: keystone.exception.NotFound
 
         """
-        raise exception.NotImplemented()
+        raise exception.NotImplemented()  # pragma: no cover
 
     def get_v3_catalog(self, user_id, tenant_id, metadata=None):
         """Retrieve and format the current V3 service catalog.
