@@ -26,31 +26,25 @@ import threading
 import time
 
 import memcache
-from oslo_log import log
-from six.moves import queue, zip
+from six.moves import queue
 
 from keystone import exception
 from keystone.i18n import _
+from keystone.openstack.common import log
 
 
 LOG = log.getLogger(__name__)
 
+# NOTE(morganfainberg): This is used as the maximum number of seconds a get
+# of a new connection will wait for before raising an exception indicating
+# a serious / most likely non-recoverable delay has occurred.
+CONNECTION_GET_TIMEOUT = 120
 
-class _MemcacheClient(memcache.Client):
-    """Thread global memcache client
-
-    As client is inherited from threading.local we have to restore object
-    methods overloaded by threading.local so we can reuse clients in
-    different threads
-    """
-    __delattr__ = object.__delattr__
-    __getattribute__ = object.__getattribute__
-    __new__ = object.__new__
-    __setattr__ = object.__setattr__
-
-    def __del__(self):
-        pass
-
+# This 'class' is taken from http://stackoverflow.com/a/22520633/238308
+# Don't inherit client from threading.local so that we can reuse clients in
+# different threads
+_MemcacheClient = type('_MemcacheClient', (object,),
+                       dict(memcache.Client.__dict__))
 
 _PoolItem = collections.namedtuple('_PoolItem', ['ttl', 'connection'])
 
@@ -78,33 +72,15 @@ class ConnectionPool(queue.Queue):
                                  indefinite.
         :type conn_get_timeout: int
         """
-        # super() cannot be used here because Queue in stdlib is an
-        # old-style class
         queue.Queue.__init__(self, maxsize)
         self._unused_timeout = unused_timeout
         self._connection_get_timeout = conn_get_timeout
         self._acquired = 0
 
     def _create_connection(self):
-        """Returns a connection instance.
-
-        This is called when the pool needs another instance created.
-
-        :returns: a new connection instance
-
-        """
         raise NotImplementedError
 
     def _destroy_connection(self, conn):
-        """Destroy and cleanup a connection instance.
-
-        This is called when the pool wishes to get rid of an existing
-        connection. This is the opportunity for a subclass to free up
-        resources and cleaup after itself.
-
-        :param conn: the connection object to destroy
-
-        """
         raise NotImplementedError
 
     def _debug_logger(self, msg, *args, **kwargs):
@@ -129,26 +105,11 @@ class ConnectionPool(queue.Queue):
             yield conn
         finally:
             self._debug_logger('Releasing connection %s', id(conn))
-            self._drop_expired_connections()
-            try:
-                # super() cannot be used here because Queue in stdlib is an
-                # old-style class
-                queue.Queue.put(self, conn, block=False)
-            except queue.Full:
-                self._debug_logger('Reaping exceeding connection %s', id(conn))
-                self._destroy_connection(conn)
+            self.put(conn)
 
     def _qsize(self):
-        if self.maxsize:
-            return self.maxsize - self._acquired
-        else:
-            # A value indicating there is always a free connection
-            # if maxsize is None or 0
-            return 1
+        return self.maxsize - self._acquired
 
-    # NOTE(dstanek): stdlib and eventlet Queue implementations
-    # have different names for the qsize method. This ensures
-    # that we override both of them.
     if not hasattr(queue.Queue, '_qsize'):
         qsize = _qsize
 
@@ -160,26 +121,22 @@ class ConnectionPool(queue.Queue):
         self._acquired += 1
         return conn
 
-    def _drop_expired_connections(self):
-        """Drop all expired connections from the right end of the queue."""
-        now = time.time()
-        while self.queue and self.queue[0].ttl < now:
-            conn = self.queue.popleft().connection
-            self._debug_logger('Reaping connection %s', id(conn))
-            self._destroy_connection(conn)
-
     def _put(self, conn):
         self.queue.append(_PoolItem(
             ttl=time.time() + self._unused_timeout,
             connection=conn,
         ))
         self._acquired -= 1
+        # Drop all expired connections from the right end of the queue
+        now = time.time()
+        while self.queue and self.queue[0].ttl < now:
+            conn = self.queue.popleft().connection
+            self._debug_logger('Reaping connection %s', id(conn))
+            self._destroy_connection(conn)
 
 
 class MemcacheClientPool(ConnectionPool):
     def __init__(self, urls, arguments, **kwargs):
-        # super() cannot be used here because Queue in stdlib is an
-        # old-style class
         ConnectionPool.__init__(self, **kwargs)
         self.urls = urls
         self._arguments = arguments
@@ -195,8 +152,6 @@ class MemcacheClientPool(ConnectionPool):
         conn.disconnect_all()
 
     def _get(self):
-        # super() cannot be used here because Queue in stdlib is an
-        # old-style class
         conn = ConnectionPool._get(self)
         try:
             # Propagate host state known to us to this client's list
@@ -208,9 +163,7 @@ class MemcacheClientPool(ConnectionPool):
         except Exception:
             # We need to be sure that connection doesn't leak from the pool.
             # This code runs before we enter context manager's try-finally
-            # block, so we need to explicitly release it here.
-            # super() cannot be used here because Queue in stdlib is an
-            # old-style class
+            # block, so we need to explicitly release it here
             ConnectionPool._put(self, conn)
             raise
         return conn
@@ -220,8 +173,9 @@ class MemcacheClientPool(ConnectionPool):
             # If this client found that one of the hosts is dead, mark it as
             # such in our internal list
             now = time.time()
-            for i, host in zip(itertools.count(), conn.servers):
-                deaduntil = self._hosts_deaduntil[i]
+            for i, deaduntil, host in zip(itertools.count(),
+                                          self._hosts_deaduntil,
+                                          conn.servers):
                 # Do nothing if we already know this host is dead
                 if deaduntil <= now:
                     if host.deaduntil > now:
@@ -239,6 +193,4 @@ class MemcacheClientPool(ConnectionPool):
                 self._debug_logger('All hosts are dead. Marking them as live.')
                 self._hosts_deaduntil[:] = [0] * len(self._hosts_deaduntil)
         finally:
-            # super() cannot be used here because Queue in stdlib is an
-            # old-style class
             ConnectionPool._put(self, conn)
