@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright 2013 Metacloud, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -28,7 +26,9 @@ import six
 
 from keystone.common import config
 from keystone import exception
-from keystone.openstack.common.gettextutils import _ # flake8: noqa
+from keystone.i18n import _
+from keystone.i18n import _LI
+from keystone.i18n import _LW
 from keystone.openstack.common import importutils
 from keystone.openstack.common import log
 
@@ -60,8 +60,8 @@ def _register_backends():
         for backend in CONF.kvs.backends:
             module, cls = backend.rsplit('.', 1)
             backend_name = prefix % cls
-            LOG.debug(_('Registering Dogpile Backend %(backend_path)s as '
-                        '%(backend_name)s'),
+            LOG.debug(('Registering Dogpile Backend %(backend_path)s as '
+                       '%(backend_name)s'),
                       {'backend_path': backend, 'backend_name': backend_name})
             region.register_backend(backend_name, module, cls)
         BACKENDS_REGISTERED = True
@@ -98,7 +98,7 @@ class KeyValueStore(object):
                                    backend for configuration
         :return:
         """
-        if 'backend' in self._region.__dict__:
+        if self.is_configured:
             # NOTE(morganfainberg): It is a bad idea to reconfigure a backend,
             # there are a lot of pitfalls and potential memory leaks that could
             # occur.  By far the best approach is to re-create the KVS object
@@ -113,13 +113,17 @@ class KeyValueStore(object):
         self._set_key_mangler(key_mangler)
         self._apply_region_proxy(proxy_list)
 
+    @property
+    def is_configured(self):
+        return 'backend' in self._region.__dict__
+
     def _apply_region_proxy(self, proxy_list):
         if isinstance(proxy_list, list):
             proxies = []
 
             for item in proxy_list:
                 if isinstance(item, str):
-                    LOG.debug(_('Importing class %s as KVS proxy.'), item)
+                    LOG.debug('Importing class %s as KVS proxy.', item)
                     pxy = importutils.import_class(item)
                 else:
                     pxy = item
@@ -127,11 +131,11 @@ class KeyValueStore(object):
                 if issubclass(pxy, proxy.ProxyBackend):
                     proxies.append(pxy)
                 else:
-                    LOG.warning(_('%s is not a dogpile.proxy.ProxyBackend'),
+                    LOG.warning(_LW('%s is not a dogpile.proxy.ProxyBackend'),
                                 pxy.__name__)
 
             for proxy_cls in reversed(proxies):
-                LOG.info(_('Adding proxy \'%(proxy)s\' to KVS %(name)s.'),
+                LOG.info(_LI('Adding proxy \'%(proxy)s\' to KVS %(name)s.'),
                          {'proxy': proxy_cls.__name__,
                           'name': self._region.name})
                 self._region.wrap(proxy_cls)
@@ -155,9 +159,9 @@ class KeyValueStore(object):
                 # Support of the feature is implied by the existence of the
                 # 'raw_no_expiry_keys' attribute.
                 if not hasattr(self._region.backend, 'raw_no_expiry_keys'):
-                    LOG.debug(_('Non-expiring keys not supported/required by '
-                                '%(region)s backend; unable to set '
-                                'key_mangler for backend: %(err)s'),
+                    LOG.debug(('Non-expiring keys not supported/required by '
+                               '%(region)s backend; unable to set '
+                               'key_mangler for backend: %(err)s'),
                               {'region': self._region.name, 'err': e})
                 else:
                     raise
@@ -181,7 +185,7 @@ class KeyValueStore(object):
 
         if CONF.kvs.enable_key_mangler:
             if key_mangler is not None:
-                msg = _('Using %(func)s as KVS region %(name)s key_mangler')
+                msg = _LI('Using %(func)s as KVS region %(name)s key_mangler')
                 if callable(key_mangler):
                     self._region.key_mangler = key_mangler
                     LOG.info(msg, {'func': key_mangler.__name__,
@@ -193,8 +197,8 @@ class KeyValueStore(object):
                     raise exception.ValidationError(
                         _('`key_mangler` option must be a function reference'))
             else:
-                LOG.info(_('Using default dogpile sha1_mangle_key as KVS '
-                           'region %s key_mangler'), self._region.name)
+                LOG.info(_LI('Using default dogpile sha1_mangle_key as KVS '
+                             'region %s key_mangler'), self._region.name)
                 # NOTE(morganfainberg): Sane 'default' keymangler is the
                 # dogpile sha1_mangle_key function.  This ensures that unless
                 # explicitly changed, we mangle keys.  This helps to limit
@@ -203,7 +207,7 @@ class KeyValueStore(object):
                 self._region.key_mangler = dogpile_util.sha1_mangle_key
             self._set_keymangler_on_backend(self._region.key_mangler)
         else:
-            LOG.info(_('KVS region %s key_mangler disabled.'),
+            LOG.info(_LI('KVS region %s key_mangler disabled.'),
                      self._region.name)
             self._set_keymangler_on_backend(None)
 
@@ -232,7 +236,7 @@ class KeyValueStore(object):
             arg_key = '.'.join([prefix, 'arguments', argument])
             conf_dict[arg_key] = value
 
-        LOG.debug(_('KVS region configuration for %(name)s: %(config)r'),
+        LOG.debug('KVS region configuration for %(name)s: %(config)r',
                   {'name': self._region.name, 'config': conf_dict})
         self._region.configure_from_config(conf_dict, '%s.' % prefix)
 
@@ -373,7 +377,7 @@ class KeyValueStoreLock(object):
     def acquire(self):
         if self.enabled:
             self.mutex.acquire()
-            LOG.debug(_('KVS lock acquired for: %s'), self.key)
+            LOG.debug('KVS lock acquired for: %s', self.key)
         self.active = True
         self.acquire_time = time.time()
         return self
@@ -392,9 +396,9 @@ class KeyValueStoreLock(object):
         if self.enabled:
             self.mutex.release()
             if not self.expired:
-                LOG.debug(_('KVS lock released for: %s'), self.key)
+                LOG.debug('KVS lock released for: %s', self.key)
             else:
-                LOG.warning(_('KVS lock released (timeout reached) for: %s'),
+                LOG.warning(_LW('KVS lock released (timeout reached) for: %s'),
                             self.key)
 
     def __exit__(self, exc_type, exc_val, exc_tb):
