@@ -20,13 +20,21 @@ by convention, with a few hardcoded exceptions.
 
 """
 
-from lxml import etree
 import re
 
 import six
 
-from keystone.openstack.common.gettextutils import _
+try:
+    from lxml import etree
+except ImportError:
+    etree = None
 
+from keystone import exception
+from keystone.i18n import _
+from keystone.openstack.common import log as logging
+
+
+LOG = logging.getLogger(__name__)
 
 DOCTYPE = '<?xml version="1.0" encoding="UTF-8"?>'
 XMLNS = 'http://docs.openstack.org/identity/api/v2.0'
@@ -39,16 +47,7 @@ XMLNS_LIST = [
         'value': 'http://docs.openstack.org/identity/api/ext/OS-KSADM/v1.0',
     },
 ]
-
-PARSER = etree.XMLParser(
-    resolve_entities=False,
-    remove_comments=True,
-    remove_pis=True)
-
-# NOTE(dolph): lxml.etree.Entity() is just a callable that currently returns an
-# lxml.etree._Entity instance, which doesn't appear to be part of the
-# public API, so we discover the type dynamically to be safe
-ENTITY_TYPE = type(etree.Entity('x'))
+E_LXML_NOT_INSTALLED = _('lxml is not installed.')
 
 
 def from_xml(xml):
@@ -70,9 +69,25 @@ def to_xml(d, xmlns=None):
 
 
 class XmlDeserializer(object):
+
+    def __init__(self):
+        if etree is None:
+            LOG.warning(E_LXML_NOT_INSTALLED)
+            raise exception.UnexpectedError(E_LXML_NOT_INSTALLED)
+
+        self.parser = etree.XMLParser(resolve_entities=False,
+                                      remove_comments=True,
+                                      remove_pis=True)
+
+        # NOTE(dolph): lxml.etree.Entity() is just a callable that currently
+        # returns an lxml.etree._Entity instance, which doesn't appear to be
+        # part of the public API, so we discover the type dynamically to be
+        # safe
+        self.entity_type = type(etree.Entity('x'))
+
     def __call__(self, xml_str):
         """Returns a dictionary populated by decoding the given xml string."""
-        dom = etree.fromstring(xml_str.strip(), PARSER)
+        dom = etree.fromstring(xml_str.strip(), self.parser)
         return self.walk_element(dom, True)
 
     def _deserialize_links(self, links):
@@ -92,17 +107,17 @@ class XmlDeserializer(object):
             return tag_name
         bracket = re.search('[^{]+$', tag)
         ns = m.string[bracket.start():m.start() - 1]
-        #If the namespace is
-        #http://docs.openstack.org/identity/api/ext/OS-KSADM/v1.0
-        #for the root element, a prefix needs to add in front of the tag name.
+        # If the namespace is
+        # http://docs.openstack.org/identity/api/ext/OS-KSADM/v1.0 for the
+        # root element, a prefix needs to add in front of the tag name.
         prefix = None
         for xmlns in XMLNS_LIST:
             if xmlns['value'] == ns:
                 prefix = xmlns.get('prefix')
                 break
         if prefix is not None:
-            return '%(PREFIX)s:%(tag_name)s' \
-                % {'PREFIX': prefix, 'tag_name': tag_name}
+            return '%(PREFIX)s:%(tag_name)s' % {
+                'PREFIX': prefix, 'tag_name': tag_name}
         else:
             return tag_name
 
@@ -145,7 +160,7 @@ class XmlDeserializer(object):
         links = None
         truncated = False
         for child in [self.walk_element(x) for x in element
-                      if not isinstance(x, ENTITY_TYPE)]:
+                      if not isinstance(x, self.entity_type)]:
             if list_item_tag:
                 # FIXME(gyee): special-case lists for now until we
                 # figure out how to properly handle them.
@@ -178,6 +193,12 @@ class XmlDeserializer(object):
 
 
 class XmlSerializer(object):
+
+    def __init__(self):
+        if etree is None:
+            LOG.warning(E_LXML_NOT_INSTALLED)
+            raise exception.UnexpectedError(E_LXML_NOT_INSTALLED)
+
     def __call__(self, d, xmlns=None):
         """Returns an xml etree populated by the given dictionary.
 
