@@ -29,7 +29,6 @@ import six
 from six import moves
 
 from keystone.common import config
-from keystone.common import environment
 from keystone import exception
 from keystone.i18n import _
 from keystone.openstack.common import jsonutils
@@ -151,43 +150,6 @@ def attr_as_boolean(val_attr):
     return strutils.bool_from_string(val_attr, default=True)
 
 
-# From python 2.7
-def check_output(*popenargs, **kwargs):
-    r"""Run command with arguments and return its output as a byte string.
-
-    If the exit code was non-zero it raises a CalledProcessError.  The
-    CalledProcessError object will have the return code in the returncode
-    attribute and output in the output attribute.
-
-    The arguments are the same as for the Popen constructor.  Example:
-
-    >>> check_output(['ls', '-l', '/dev/null'])
-    'crw-rw-rw- 1 root root 1, 3 Oct 18  2007 /dev/null\n'
-
-    The stdout argument is not allowed as it is used internally.
-    To capture standard error in the result, use stderr=STDOUT.
-
-    >>> import sys
-    >>> check_output(['/bin/sh', '-c',
-    ...               'ls -l non_existent_file ; exit 0'],
-    ...              stderr=sys.STDOUT)
-    'ls: non_existent_file: No such file or directory\n'
-    """
-    if 'stdout' in kwargs:
-        raise ValueError('stdout argument not allowed, it will be overridden.')
-    LOG.debug(' '.join(popenargs[0]))
-    process = environment.subprocess.Popen(stdout=environment.subprocess.PIPE,
-                                           *popenargs, **kwargs)
-    output, unused_err = process.communicate()
-    retcode = process.poll()
-    if retcode:
-        cmd = kwargs.get('args')
-        if cmd is None:
-            cmd = popenargs[0]
-        raise environment.subprocess.CalledProcessError(retcode, cmd)
-    return output
-
-
 def get_blob_from_credential(credential):
     try:
         blob = jsonutils.loads(credential.blob)
@@ -220,10 +182,6 @@ def convert_v3_to_ec2_credential(credential):
             }
 
 
-def git(*args):
-    return check_output(['git'] + list(args))
-
-
 def unixtime(dt_obj):
     """Format datetime object as unix timestamp
 
