@@ -12,26 +12,53 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import webob
+
 from keystone.common import extension
+from keystone.common import json_home
 from keystone.common import wsgi
-from keystone import config
 from keystone import exception
+from keystone.openstack.common import jsonutils
 from keystone.openstack.common import log
 
 
 LOG = log.getLogger(__name__)
-CONF = config.CONF
 
 MEDIA_TYPE_JSON = 'application/vnd.openstack.identity-%s+json'
 MEDIA_TYPE_XML = 'application/vnd.openstack.identity-%s+xml'
 
 _VERSIONS = []
 
+# NOTE(blk-u): latest_app will be set by keystone.service.loadapp(). It gets
+# set to the application that was just loaded. In the case of keystone-all,
+# loadapp() gets called twice, once for the public app and once for the admin
+# app. In the case of httpd/keystone, loadapp() gets called once for the public
+# app if this is the public instance or loadapp() gets called for the admin app
+# if it's the admin instance.
+# This is used to fetch the /v3 JSON Home response. The /v3 JSON Home response
+# is the same whether it's the admin or public service so either admin or
+# public works.
+latest_app = None
+
+
+def request_v3_json_home(new_prefix):
+    if 'v3' not in _VERSIONS:
+        # No V3 support, so return an empty JSON Home document.
+        return {'resources': {}}
+
+    req = webob.Request.blank(
+        '/v3', headers={'Accept': 'application/json-home'})
+    v3_json_home_str = req.get_response(latest_app).body
+    v3_json_home = jsonutils.loads(v3_json_home_str)
+    json_home.translate_urls(v3_json_home, new_prefix)
+
+    return v3_json_home
+
 
 class Extensions(wsgi.Application):
     """Base extensions controller to be extended by public and admin API's."""
 
-    #extend in subclass to specify the set of extensions
+    # extend in subclass to specify the set of extensions
     @property
     def extensions(self):
         return None
@@ -62,10 +89,28 @@ def register_version(version):
     _VERSIONS.append(version)
 
 
+class MimeTypes:
+    JSON = 'application/json'
+    JSON_HOME = 'application/json-home'
+
+
+def v3_mime_type_best_match(context):
+
+    # accept_header is a WebOb MIMEAccept object so supports best_match.
+    accept_header = context['accept_header']
+
+    if not accept_header:
+        return MimeTypes.JSON
+
+    SUPPORTED_TYPES = [MimeTypes.JSON, MimeTypes.JSON_HOME]
+    return accept_header.best_match(SUPPORTED_TYPES)
+
+
 class Version(wsgi.Application):
 
-    def __init__(self, version_type):
+    def __init__(self, version_type, routers=None):
         self.endpoint_url_type = version_type
+        self._routers = routers
 
         super(Version, self).__init__()
 
@@ -89,14 +134,7 @@ class Version(wsgi.Application):
                     }, {
                         'rel': 'describedby',
                         'type': 'text/html',
-                        'href': 'http://docs.openstack.org/api/openstack-'
-                                'identity-service/2.0/content/'
-                    }, {
-                        'rel': 'describedby',
-                        'type': 'application/pdf',
-                        'href': 'http://docs.openstack.org/api/openstack-'
-                                'identity-service/2.0/identity-dev-guide-'
-                                '2.0.pdf'
+                        'href': 'http://docs.openstack.org/'
                     }
                 ],
                 'media-types': [
@@ -135,6 +173,14 @@ class Version(wsgi.Application):
         return versions
 
     def get_versions(self, context):
+
+        req_mime_type = v3_mime_type_best_match(context)
+        if req_mime_type == MimeTypes.JSON_HOME:
+            v3_json_home = request_v3_json_home('/v3')
+            return wsgi.render_response(
+                body=v3_json_home,
+                headers=(('Content-Type', MimeTypes.JSON_HOME),))
+
         versions = self._get_versions_list(context)
         return wsgi.render_response(status=(300, 'Multiple Choices'), body={
             'versions': {
@@ -151,9 +197,27 @@ class Version(wsgi.Application):
         else:
             raise exception.VersionNotFound(version='v2.0')
 
+    def _get_json_home_v3(self):
+
+        def all_resources():
+            for router in self._routers:
+                for resource in router.v3_resources:
+                    yield resource
+
+        return {
+            'resources': dict(all_resources())
+        }
+
     def get_version_v3(self, context):
         versions = self._get_versions_list(context)
         if 'v3' in _VERSIONS:
+            req_mime_type = v3_mime_type_best_match(context)
+
+            if req_mime_type == MimeTypes.JSON_HOME:
+                return wsgi.render_response(
+                    body=self._get_json_home_v3(),
+                    headers=(('Content-Type', MimeTypes.JSON_HOME),))
+
             return wsgi.render_response(body={
                 'version': versions['v3']
             })
