@@ -16,10 +16,13 @@
 import os
 import shutil
 
+import mock
+from testtools import matchers
+
+from keystone.common import environment
 from keystone.common import openssl
 from keystone import exception
 from keystone import tests
-from keystone.tests import default_fixtures
 from keystone.tests import rest
 from keystone import token
 
@@ -37,9 +40,6 @@ class CertSetupTestCase(rest.RestfulTestCase):
 
     def setUp(self):
         super(CertSetupTestCase, self).setUp()
-        self.load_backends()
-        self.load_fixtures(default_fixtures)
-        self.controller = token.controllers.Auth()
 
         def cleanup_ssldir():
             try:
@@ -66,24 +66,29 @@ class CertSetupTestCase(rest.RestfulTestCase):
             ca_key=ca_key,
             certfile=os.path.join(CERTDIR, 'keystone.pem'),
             keyfile=os.path.join(KEYDIR, 'keystonekey.pem'))
+        self.config_fixture.config(
+            group='token',
+            provider='keystone.token.providers.pkiz.Provider')
 
     def test_can_handle_missing_certs(self):
+        controller = token.controllers.Auth()
+
         self.config_fixture.config(group='signing', certfile='invalid')
+        password = 'fake1'
         user = {
-            'id': 'fake1',
             'name': 'fake1',
-            'password': 'fake1',
+            'password': password,
             'domain_id': DEFAULT_DOMAIN_ID
         }
+        user = self.identity_api.create_user(user)
         body_dict = {
             'passwordCredentials': {
                 'userId': user['id'],
-                'password': user['password'],
+                'password': password,
             },
         }
-        self.identity_api.create_user(user['id'], user)
         self.assertRaises(exception.UnexpectedError,
-                          self.controller.authenticate,
+                          controller.authenticate,
                           {}, body_dict)
 
     def test_create_pki_certs(self):
@@ -115,10 +120,10 @@ class CertSetupTestCase(rest.RestfulTestCase):
                                    method='GET', expected_status=200)
 
         with open(CONF.signing.certfile) as f:
-            self.assertEqual(signing_resp.text, f.read())
+            self.assertEqual(f.read(), signing_resp.text)
 
         with open(CONF.signing.ca_certs) as f:
-            self.assertEqual(cacert_resp.text, f.read())
+            self.assertEqual(f.read(), cacert_resp.text)
 
         # NOTE(jamielennox): This is weird behaviour that we need to enforce.
         # It doesn't matter what you ask for it's always going to give text
@@ -131,9 +136,34 @@ class CertSetupTestCase(rest.RestfulTestCase):
                                     expected_status=200,
                                     headers=headers)
 
-                self.assertEqual(resp.content_type, 'text/html')
+                self.assertEqual('text/html', resp.content_type)
 
     def test_failure(self):
         for path in ['/v2.0/certificates/signing', '/v2.0/certificates/ca']:
             self.request(self.public_app, path, method='GET',
                          expected_status=500)
+
+
+class TestExecCommand(tests.TestCase):
+
+    @mock.patch.object(environment.subprocess.Popen, 'poll')
+    def test_running_a_successful_command(self, mock_poll):
+        mock_poll.return_value = 0
+
+        ssl = openssl.ConfigureSSL('keystone_user', 'keystone_group')
+        ssl.exec_command(['ls'])
+
+    @mock.patch.object(environment.subprocess.Popen, 'communicate')
+    @mock.patch.object(environment.subprocess.Popen, 'poll')
+    def test_running_an_invalid_command(self, mock_poll, mock_communicate):
+        output = 'this is the output string'
+
+        mock_communicate.return_value = (output, '')
+        mock_poll.return_value = 1
+
+        cmd = ['ls']
+        ssl = openssl.ConfigureSSL('keystone_user', 'keystone_group')
+        e = self.assertRaises(environment.subprocess.CalledProcessError,
+                              ssl.exec_command,
+                              cmd)
+        self.assertThat(e.output, matchers.Equals(output))
