@@ -12,10 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-
-from keystone.tests import core as test
-
 from keystone.common import driver_hints
+from keystone.tests import core as test
 
 
 class ListHintsTests(test.TestCase):
@@ -24,39 +22,39 @@ class ListHintsTests(test.TestCase):
         hints = driver_hints.Hints()
         hints.add_filter('t1', 'data1')
         hints.add_filter('t2', 'data2')
-        self.assertEqual(len(hints.filters()), 2)
+        self.assertEqual(2, len(hints.filters))
         filter = hints.get_exact_filter_by_name('t1')
-        self.assertEqual(filter['name'], 't1')
-        self.assertEqual(filter['value'], 'data1')
-        self.assertEqual(filter['comparator'], 'equals')
-        self.assertEqual(filter['case_sensitive'], False)
+        self.assertEqual('t1', filter['name'])
+        self.assertEqual('data1', filter['value'])
+        self.assertEqual('equals', filter['comparator'])
+        self.assertEqual(False, filter['case_sensitive'])
 
-        hints.remove(filter)
+        hints.filters.remove(filter)
         filter_count = 0
-        for filter in hints.filters():
+        for filter in hints.filters:
             filter_count += 1
-            self.assertEqual(filter['name'], 't2')
-        self.assertEqual(filter_count, 1)
+            self.assertEqual('t2', filter['name'])
+        self.assertEqual(1, filter_count)
 
     def test_multiple_creates(self):
         hints = driver_hints.Hints()
         hints.add_filter('t1', 'data1')
         hints.add_filter('t2', 'data2')
-        self.assertEqual(len(hints.filters()), 2)
+        self.assertEqual(2, len(hints.filters))
         hints2 = driver_hints.Hints()
         hints2.add_filter('t4', 'data1')
         hints2.add_filter('t5', 'data2')
-        self.assertEqual(len(hints.filters()), 2)
+        self.assertEqual(2, len(hints.filters))
 
     def test_limits(self):
         hints = driver_hints.Hints()
-        self.assertIsNone(hints.get_limit())
+        self.assertIsNone(hints.limit)
         hints.set_limit(10)
-        self.assertEqual(hints.get_limit()['limit'], 10)
-        self.assertFalse(hints.get_limit()['truncated'])
+        self.assertEqual(10, hints.limit['limit'])
+        self.assertFalse(hints.limit['truncated'])
         hints.set_limit(11)
-        self.assertEqual(hints.get_limit()['limit'], 11)
-        self.assertFalse(hints.get_limit()['truncated'])
+        self.assertEqual(11, hints.limit['limit'])
+        self.assertFalse(hints.limit['truncated'])
         hints.set_limit(10, truncated=True)
-        self.assertEqual(hints.get_limit()['limit'], 10)
-        self.assertTrue(hints.get_limit()['truncated'])
+        self.assertEqual(10, hints.limit['limit'])
+        self.assertTrue(hints.limit['truncated'])
