@@ -17,15 +17,11 @@ import uuid
 import six
 
 from keystone.common import wsgi
-from keystone import config
 from keystone import exception
 from keystone.openstack.common import jsonutils
 from keystone import tests
 
 
-CONF = config.CONF
-
-
 class ExceptionTestCase(tests.TestCase):
     def assertValidJsonRendering(self, e):
         resp = wsgi.render_exception(e)
@@ -53,7 +49,7 @@ class ExceptionTestCase(tests.TestCase):
         """
         for cls in [x for x in exception.__dict__.values() if callable(x)]:
             if cls is not exception.Error and isinstance(cls, exception.Error):
-                self.assertValidJsonRendering(cls(message='Overriden.'))
+                self.assertValidJsonRendering(cls(message='Overridden.'))
 
     def test_validation_error(self):
         target = uuid.uuid4().hex
