@@ -14,21 +14,17 @@
 #    under the License.
 
 import json
-import tempfile
 
+import mock
 import six
 from six.moves.urllib import request as urlrequest
 from testtools import matchers
 
-from keystone import config
 from keystone import exception
-from keystone.openstack.common.fixture import moxstubout
 from keystone.openstack.common import policy as common_policy
 from keystone.policy.backends import rules
 from keystone import tests
-
-
-CONF = config.CONF
+from keystone.tests.ksfixtures import temporaryfile
 
 
 class PolicyFileTestCase(tests.TestCase):
@@ -36,7 +32,8 @@ class PolicyFileTestCase(tests.TestCase):
         # self.tmpfilename should exist before setUp super is called
         # this is to ensure it is available for the config_fixture in
         # the config_overrides call.
-        _unused, self.tmpfilename = tempfile.mkstemp()
+        self.tempfile = self.useFixture(temporaryfile.SecureTempFile())
+        self.tmpfilename = self.tempfile.file_name
         super(PolicyFileTestCase, self).setUp()
 
         rules.reset()
@@ -86,9 +83,6 @@ class PolicyTestCase(tests.TestCase):
         self.credentials = {}
         self.target = {}
 
-        fixture = self.useFixture(moxstubout.MoxStubout())
-        self.stubs = fixture.stubs
-
     def _set_rules(self):
         these_rules = common_policy.Rules(
             dict((k, common_policy.parse_rule(v))
@@ -114,21 +108,22 @@ class PolicyTestCase(tests.TestCase):
         def fakeurlopen(url, post_data):
             return six.StringIO("True")
 
-        self.stubs.Set(urlrequest, 'urlopen', fakeurlopen)
         action = "example:get_http"
         target = {}
-        result = rules.enforce(self.credentials, action, target)
+        with mock.patch.object(urlrequest, 'urlopen', fakeurlopen):
+            result = rules.enforce(self.credentials, action, target)
         self.assertTrue(result)
 
     def test_enforce_http_false(self):
 
         def fakeurlopen(url, post_data):
             return six.StringIO("False")
-        self.stubs.Set(urlrequest, 'urlopen', fakeurlopen)
+
         action = "example:get_http"
         target = {}
-        self.assertRaises(exception.ForbiddenAction, rules.enforce,
-                          self.credentials, action, target)
+        with mock.patch.object(urlrequest, 'urlopen', fakeurlopen):
+            self.assertRaises(exception.ForbiddenAction, rules.enforce,
+                              self.credentials, action, target)
 
     def test_templatized_enforcement(self):
         target_mine = {'project_id': 'fake'}
@@ -211,7 +206,7 @@ class DefaultPolicyTestCase(tests.TestCase):
 class PolicyJsonTestCase(tests.TestCase):
 
     def _load_entries(self, filename):
-        return set(json.load(file(filename)))
+        return set(json.load(open(filename)))
 
     def test_json_examples_have_matching_entries(self):
         policy_keys = self._load_entries(tests.dirs.etc('policy.json'))
