@@ -14,11 +14,13 @@
 
 import datetime
 
+from oslo.utils import timeutils
+
 from keystone import config
 from keystone import exception
-from keystone.openstack.common import timeutils
 from keystone import tests
 from keystone.tests import default_fixtures
+from keystone.tests.ksfixtures import database
 from keystone import token
 from keystone.token.providers import pki
 
@@ -32,7 +34,9 @@ SAMPLE_V2_TOKEN = {
     "access": {
         "trust": {
             "id": "abc123",
-            "trustee_user_id": "123456"
+            "trustee_user_id": "123456",
+            "trustor_user_id": "333333",
+            "impersonation": False
         },
         "serviceCatalog": [
             {
@@ -339,7 +343,9 @@ SAMPLE_V2_TOKEN_WITH_EMBEDED_VERSION = {
     "access": {
         "trust": {
             "id": "abc123",
-            "trustee_user_id": "123456"
+            "trustee_user_id": "123456",
+            "trustor_user_id": "333333",
+            "impersonation": False
         },
         "serviceCatalog": [
             {
@@ -705,6 +711,7 @@ SAMPLE_MALFORMED_TOKEN = {
 class TestTokenProvider(tests.TestCase):
     def setUp(self):
         super(TestTokenProvider, self).setUp()
+        self.useFixture(database.Database())
         self.load_backends()
 
     def test_get_token_version(self):
@@ -722,40 +729,18 @@ class TestTokenProvider(tests.TestCase):
             token.provider.V3,
             self.token_provider_api.get_token_version(
                 SAMPLE_V3_TOKEN_WITH_EMBEDED_VERSION))
-        self.assertRaises(token.provider.UnsupportedTokenVersionException,
+        self.assertRaises(exception.UnsupportedTokenVersionException,
                           self.token_provider_api.get_token_version,
                           'bogus')
 
-    def test_token_format_provider_mismatch(self):
-        self.config_fixture.config(group='signing', token_format='UUID')
-        self.config_fixture.config(group='token',
-                                   provider=token.provider.PKI_PROVIDER)
-        self.assertRaises(exception.UnexpectedError, token.provider.Manager)
-
-        self.config_fixture.config(group='signing', token_format='PKI')
-        self.config_fixture.config(group='token',
-                                   provider=token.provider.UUID_PROVIDER)
-        self.assertRaises(exception.UnexpectedError, token.provider.Manager)
-
-        # should be OK as token_format and provider aligns
-        self.config_fixture.config(group='signing', token_format='PKI')
-        self.config_fixture.config(group='token',
-                                   provider=token.provider.PKI_PROVIDER)
-        token.provider.Manager()
-
-        self.config_fixture.config(group='signing', token_format='UUID')
-        self.config_fixture.config(group='token',
-                                   provider=token.provider.UUID_PROVIDER)
-        token.provider.Manager()
-
     def test_default_token_format(self):
-        self.assertEqual(token.provider.Manager.get_token_provider(),
-                         token.provider.PKI_PROVIDER)
+        self.assertEqual(token.provider.UUID_PROVIDER,
+                         token.provider.Manager.get_token_provider())
 
     def test_uuid_token_format_and_no_provider(self):
         self.config_fixture.config(group='signing', token_format='UUID')
-        self.assertEqual(token.provider.Manager.get_token_provider(),
-                         token.provider.UUID_PROVIDER)
+        self.assertEqual(token.provider.UUID_PROVIDER,
+                         token.provider.Manager.get_token_provider())
 
     def test_default_providers_without_token_format(self):
         self.config_fixture.config(group='token',
@@ -766,6 +751,10 @@ class TestTokenProvider(tests.TestCase):
                                    provider=token.provider.PKI_PROVIDER)
         token.provider.Manager()
 
+        self.config_fixture.config(group='token',
+                                   provider=token.provider.PKIZ_PROVIDER)
+        token.provider.Manager()
+
     def test_unsupported_token_format(self):
         self.config_fixture.config(group='signing', token_format='CUSTOM')
         self.assertRaises(exception.UnexpectedError,
@@ -774,33 +763,33 @@ class TestTokenProvider(tests.TestCase):
     def test_uuid_provider(self):
         self.config_fixture.config(group='token',
                                    provider=token.provider.UUID_PROVIDER)
-        self.assertEqual(token.provider.Manager.get_token_provider(),
-                         token.provider.UUID_PROVIDER)
+        self.assertEqual(token.provider.UUID_PROVIDER,
+                         token.provider.Manager.get_token_provider())
 
     def test_provider_override_token_format(self):
         self.config_fixture.config(
             group='token',
             provider='keystone.token.providers.pki.Test')
-        self.assertEqual(token.provider.Manager.get_token_provider(),
-                         'keystone.token.providers.pki.Test')
+        self.assertEqual('keystone.token.providers.pki.Test',
+                         token.provider.Manager.get_token_provider())
 
         self.config_fixture.config(group='signing', token_format='UUID')
         self.config_fixture.config(group='token',
                                    provider=token.provider.UUID_PROVIDER)
-        self.assertEqual(token.provider.Manager.get_token_provider(),
-                         token.provider.UUID_PROVIDER)
+        self.assertEqual(token.provider.UUID_PROVIDER,
+                         token.provider.Manager.get_token_provider())
 
         self.config_fixture.config(group='signing', token_format='PKI')
         self.config_fixture.config(group='token',
                                    provider=token.provider.PKI_PROVIDER)
-        self.assertEqual(token.provider.Manager.get_token_provider(),
-                         token.provider.PKI_PROVIDER)
+        self.assertEqual(token.provider.PKI_PROVIDER,
+                         token.provider.Manager.get_token_provider())
 
         self.config_fixture.config(group='signing', token_format='CUSTOM')
         self.config_fixture.config(group='token',
                                    provider='my.package.MyProvider')
-        self.assertEqual(token.provider.Manager.get_token_provider(),
-                         'my.package.MyProvider')
+        self.assertRaises(exception.UnexpectedError,
+                          token.provider.Manager.get_token_provider)
 
     def test_provider_token_expiration_validation(self):
         self.assertRaises(exception.TokenNotFound,
@@ -812,17 +801,16 @@ class TestTokenProvider(tests.TestCase):
         self.assertRaises(exception.TokenNotFound,
                           self.token_provider_api._is_valid_token,
                           SAMPLE_MALFORMED_TOKEN)
-        self.assertEqual(
-            None,
+        self.assertIsNone(
             self.token_provider_api._is_valid_token(create_v2_token()))
-        self.assertEqual(
-            None,
+        self.assertIsNone(
             self.token_provider_api._is_valid_token(create_v3_token()))
 
 
 class TestTokenProviderOAuth1(tests.TestCase):
     def setUp(self):
         super(TestTokenProviderOAuth1, self).setUp()
+        self.useFixture(database.Database())
         self.load_backends()
 
     def config_overrides(self):
@@ -838,10 +826,11 @@ class TestTokenProviderOAuth1(tests.TestCase):
                           self.user_foo['id'], ['oauth1'])
 
 
-class TestPKIProvider(object):
+# NOTE(ayoung): renamed to avoid automatic test detection
+class PKIProviderTests(object):
 
     def setUp(self):
-        super(TestPKIProvider, self).setUp()
+        super(PKIProviderTests, self).setUp()
 
         from keystoneclient.common import cms
         self.cms = cms
@@ -872,7 +861,7 @@ class TestPKIProvider(object):
                           token_data)
 
 
-class TestPKIProviderWithEventlet(TestPKIProvider, tests.TestCase):
+class TestPKIProviderWithEventlet(PKIProviderTests, tests.TestCase):
 
     def setUp(self):
         # force keystoneclient.common.cms to use eventlet's subprocess
@@ -882,7 +871,7 @@ class TestPKIProviderWithEventlet(TestPKIProvider, tests.TestCase):
         super(TestPKIProviderWithEventlet, self).setUp()
 
 
-class TestPKIProviderWithStdlib(TestPKIProvider, tests.TestCase):
+class TestPKIProviderWithStdlib(PKIProviderTests, tests.TestCase):
 
     def setUp(self):
         # force keystoneclient.common.cms to use the stdlib subprocess
