@@ -13,13 +13,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import tempfile
 import uuid
 
 from keystone import config
 from keystone.openstack.common import jsonutils
 from keystone.policy.backends import rules
 from keystone.tests import filtering
+from keystone.tests.ksfixtures import temporaryfile
 from keystone.tests import test_v3
 
 
@@ -40,10 +40,11 @@ class IdentityTestFilteredCase(filtering.FilterTests,
         # file in each test to create the policies
         self.orig_policy_file = CONF.policy_file
         rules.reset()
-        _unused, self.tmpfilename = tempfile.mkstemp()
+        self.tempfile = self.useFixture(temporaryfile.SecureTempFile())
+        self.tmpfilename = self.tempfile.file_name
         self.config_fixture.config(policy_file=self.tmpfilename)
 
-        #drop the policy rules
+        # drop the policy rules
         self.addCleanup(rules.reset)
 
     def load_sample_data(self):
@@ -62,6 +63,7 @@ class IdentityTestFilteredCase(filtering.FilterTests,
 
         """
         # Start by creating a few domains
+        self._populate_default_domain()
         self.domainA = self.new_domain_ref()
         self.assignment_api.create_domain(self.domainA['id'], self.domainA)
         self.domainB = self.new_domain_ref()
@@ -72,16 +74,20 @@ class IdentityTestFilteredCase(filtering.FilterTests,
 
         # Now create some users, one in domainA and two of them in domainB
         self.user1 = self.new_user_ref(domain_id=self.domainA['id'])
-        self.user1['password'] = uuid.uuid4().hex
-        self.identity_api.create_user(self.user1['id'], self.user1)
+        password = uuid.uuid4().hex
+        self.user1['password'] = password
+        self.user1 = self.identity_api.create_user(self.user1)
+        self.user1['password'] = password
 
         self.user2 = self.new_user_ref(domain_id=self.domainB['id'])
-        self.user2['password'] = uuid.uuid4().hex
-        self.identity_api.create_user(self.user2['id'], self.user2)
+        self.user2['password'] = password
+        self.user2 = self.identity_api.create_user(self.user2)
+        self.user2['password'] = password
 
         self.user3 = self.new_user_ref(domain_id=self.domainB['id'])
-        self.user3['password'] = uuid.uuid4().hex
-        self.identity_api.create_user(self.user3['id'], self.user3)
+        self.user3['password'] = password
+        self.user3 = self.identity_api.create_user(self.user3)
+        self.user3['password'] = password
 
         self.role = self.new_role_ref()
         self.assignment_api.create_role(self.role['id'], self.role)
@@ -289,7 +295,7 @@ class IdentityTestFilteredCase(filtering.FilterTests,
         # See if we can add a SQL command...use the group table instead of the
         # user table since 'user' is reserved word for SQLAlchemy.
         group = self.new_group_ref(domain_id=self.domainB['id'])
-        self.identity_api.create_group(group['id'], group)
+        group = self.identity_api.create_group(group)
 
         url_by_name = "/users?name=x'; drop table group"
         r = self.get(url_by_name, auth=self.auth)
