@@ -17,6 +17,7 @@
 import abc
 import copy
 
+from oslo.utils import timeutils
 import six
 
 from keystone.common import cache
@@ -24,8 +25,8 @@ from keystone.common import dependency
 from keystone.common import manager
 from keystone import config
 from keystone import exception
+from keystone.i18n import _LW
 from keystone.openstack.common import log
-from keystone.openstack.common import timeutils
 from keystone.openstack.common import versionutils
 
 
@@ -40,8 +41,7 @@ REVOCATION_CACHE_EXPIRATION_TIME = lambda: CONF.token.revocation_cache_time
 
 @dependency.requires('assignment_api', 'identity_api', 'token_provider_api',
                      'trust_api')
-@dependency.provider('token_api')
-class Manager(manager.Manager):
+class PersistenceManager(manager.Manager):
     """Default pivot point for the Token backend.
 
     See :mod:`keystone.common.manager.Manager` for more details on how this
@@ -50,7 +50,7 @@ class Manager(manager.Manager):
     """
 
     def __init__(self):
-        super(Manager, self).__init__(CONF.token.driver)
+        super(PersistenceManager, self).__init__(CONF.token.driver)
 
     @versionutils.deprecated(as_of=versionutils.deprecated.JUNO,
                              in_favor_of='token_provider_api.unique_id',
@@ -208,6 +208,42 @@ class Manager(manager.Manager):
         self.token_provider_api.invalidate_individual_token_cache(token_id)
 
 
+# NOTE(morganfainberg): @dependency.optional() is required here to ensure the
+# class-level optional dependency control attribute is populated as empty
+# this is because of the override of .__getattr__ and ensures that if the
+# optional dependency injector changes attributes, this class doesn't break.
+@dependency.optional()
+@dependency.requires('token_provider_api')
+@dependency.provider('token_api')
+class Manager(object):
+    """The token_api provider.
+
+    This class is a proxy class to the token_provider_api's persistence
+    manager.
+    """
+    def __init__(self):
+        # NOTE(morganfainberg): __init__ is required for dependency processing.
+        super(Manager, self).__init__()
+
+    def __getattr__(self, item):
+        """Forward calls to the `token_provider_api` persistence manager."""
+
+        # NOTE(morganfainberg): Prevent infinite recursion, raise an
+        # AttributeError for 'token_provider_api' ensuring that the dep
+        # injection doesn't infinitely try and lookup self.token_provider_api
+        # on _process_dependencies. This doesn't need an exception string as
+        # it should only ever be hit on instantiation.
+        if item == 'token_provider_api':
+            raise AttributeError()
+
+        f = getattr(self.token_provider_api._persistence, item)
+        LOG.warning(_LW('`token_api.%s` is deprecated as of Juno in favor of '
+                        'utilizing methods on `token_provider_api` and may be '
+                        'removed in Kilo.'), item)
+        setattr(self, item, f)
+        return f
+
+
 @six.add_metaclass(abc.ABCMeta)
 class Driver(object):
     """Interface description for a Token driver."""
